# TeX2JB

A CLI tool that converts LaTeX documents to Jupyter Books.

## Installation

### PyPI

```sh
pip install tex2jb
```

### Poetry

```sh
poetry add tex2jb
```

### Building from Source

```sh
git clone https://github.com/Isaac-Fate/tex2jb.git
cd tex2jb
pip install -e .
```

## Usage

```sh
tex2jb <tex_path> <book_dir>
```

For complete usage, run

```sh
tex2jb --help
```
